@@ -2,8 +2,8 @@ import pytest
 import {{ project }}
 
 
-def test_some_functionality():
-    # Write tour test functions in this file
+def test_some_basic_functionality_about():
+    assert 2 == 1 + 1
 
 
 if __name__ == '__main__':
